@@ -159,7 +159,7 @@ class Postgres_Handler:
         # table_name = kwargs[self.table_name_key]
         
         #Begining of the SQL query
-        query = sql.sql(
+        query = sql(
             'INSERT INTO {table_name} ({columns}) VALUES({values})'.format(
                 columns = sql.SQL(', ').join(
                     map(sql.Identifier, kwargs.keys())
